==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderWebhookFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ACMEIssuerDNS01ProviderWebhookFluent<A extends ACMEIssuerDNS01ProviderWebhookFluent<A>> extends BaseFluent<A>{
  public ACMEIssuerDNS01ProviderWebhookFluent() {
  }
  public ACMEIssuerDNS01ProviderWebhookFluent(ACMEIssuerDNS01ProviderWebhook instance) {
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderWebhook());

    if (instance != null) {
      this.withConfig(instance.getConfig());
      this.withGroupName(instance.getGroupName());
      this.withSolverName(instance.getSolverName());
      this.withConfig(instance.getConfig());
      this.withGroupName(instance.getGroupName());
      this.withSolverName(instance.getSolverName());
    }
  }
  private JsonNode config;
  private String groupName;
  private String solverName;
  public JsonNode getConfig() {
    return this.config;
  }
  public A withConfig(JsonNode config) {
    this.config=config; return (A) this;
  }
  public boolean hasConfig() {
    return this.config != null;
  }
  public String getGroupName() {
    return this.groupName;
  }
  public A withGroupName(String groupName) {
    this.groupName=groupName; return (A) this;
  }
  public boolean hasGroupName() {
    return this.groupName != null;
  }
  public String getSolverName() {
    return this.solverName;
  }
  public A withSolverName(String solverName) {
    this.solverName=solverName; return (A) this;
  }
  public boolean hasSolverName() {
    return this.solverName != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderWebhookFluent that = (ACMEIssuerDNS01ProviderWebhookFluent) o;
    if (!java.util.Objects.equals(config, that.config)) return false;

    if (!java.util.Objects.equals(groupName, that.groupName)) return false;

    if (!java.util.Objects.equals(solverName, that.solverName)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(config,  groupName,  solverName,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (groupName != null) { sb.append("groupName:"); sb.append(groupName + ","); }
    if (solverName != null) { sb.append("solverName:"); sb.append(solverName); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/ACMEIssuerDNS01ProviderWebhookFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import com.fasterxml.jackson.databind.JsonNode;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class ACMEIssuerDNS01ProviderWebhookFluent<A extends ACMEIssuerDNS01ProviderWebhookFluent<A>> extends BaseFluent<A>{
  public ACMEIssuerDNS01ProviderWebhookFluent() {
  }
  
  public ACMEIssuerDNS01ProviderWebhookFluent(ACMEIssuerDNS01ProviderWebhook instance) {
    this.copyInstance(instance);
  }
  private JsonNode config;
  private String groupName;
  private String solverName;
  
  protected void copyInstance(ACMEIssuerDNS01ProviderWebhook instance) {
    instance = (instance != null ? instance : new ACMEIssuerDNS01ProviderWebhook());
  
    if (instance != null) {
        this.withConfig(instance.getConfig());
        this.withGroupName(instance.getGroupName());
        this.withSolverName(instance.getSolverName());
        this.withConfig(instance.getConfig());
        this.withGroupName(instance.getGroupName());
        this.withSolverName(instance.getSolverName());
      }
  }
  
  public JsonNode getConfig() {
    return this.config;
  }
  
  public A withConfig(JsonNode config) {
    this.config=config; return (A) this;
  }
  
  public boolean hasConfig() {
    return this.config != null;
  }
  
  public String getGroupName() {
    return this.groupName;
  }
  
  public A withGroupName(String groupName) {
    this.groupName=groupName; return (A) this;
  }
  
  public boolean hasGroupName() {
    return this.groupName != null;
  }
  
  public String getSolverName() {
    return this.solverName;
  }
  
  public A withSolverName(String solverName) {
    this.solverName=solverName; return (A) this;
  }
  
  public boolean hasSolverName() {
    return this.solverName != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ACMEIssuerDNS01ProviderWebhookFluent that = (ACMEIssuerDNS01ProviderWebhookFluent) o;
    if (!java.util.Objects.equals(config, that.config)) return false;
  
    if (!java.util.Objects.equals(groupName, that.groupName)) return false;
  
    if (!java.util.Objects.equals(solverName, that.solverName)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(config,  groupName,  solverName,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (config != null) { sb.append("config:"); sb.append(config + ","); }
    if (groupName != null) { sb.append("groupName:"); sb.append(groupName + ","); }
    if (solverName != null) { sb.append("solverName:"); sb.append(solverName); }
    sb.append("}");
    return sb.toString();
  }
  

}
